@@ -8,9 +8,9 @@ import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
 import com.openexchange.admin.soap.context.dataobjects.Context;
 import com.openexchange.admin.soap.context.dataobjects.Credentials;
+import com.openexchange.admin.soap.context.dataobjects.SchemaSelectStrategy;
 import com.openexchange.admin.soap.context.dataobjects.User;
 
-
 /**
  * <p>Java-Klasse f\u00fcr anonymous complex type.
  *
@@ -18,15 +18,16 @@ import com.openexchange.admin.soap.context.dataobjects.User;
  *
  * <pre>
  * &lt;complexType>
- *   &lt;complexContent>
- *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- *       &lt;sequence>
- *         &lt;element name="ctx" type="{http://dataobjects.soap.admin.openexchange.com/xsd}Context" minOccurs="0"/>
- *         &lt;element name="admin_user" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" minOccurs="0"/>
- *         &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
- *       &lt;/sequence>
- *     &lt;/restriction>
- *   &lt;/complexContent>
+ * &lt;complexContent>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ * &lt;sequence>
+ * &lt;element name="ctx" type="{http://dataobjects.soap.admin.openexchange.com/xsd}Context" minOccurs="0"/>
+ * &lt;element name="admin_user" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" minOccurs="0"/>
+ * &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
+ * &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}SchemaSelectStrategy" minOccurs="0"/>
+ * &lt;/sequence>
+ * &lt;/restriction>
+ * &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
  *
@@ -36,7 +37,8 @@ import com.openexchange.admin.soap.context.dataobjects.User;
 @XmlType(name = "", propOrder = {
     "ctx",
     "adminUser",
-    "auth"
+    "auth",
+    "schemaSelectStrategy"
 })
 @XmlRootElement(name = "create")
 public class Create {
@@ -47,13 +49,14 @@ public class Create {
     protected User adminUser;
     @XmlElement(nillable = true)
     protected Credentials auth;
+    @XmlElement(name = "schema_select_strategy", nillable = true)
+    private SchemaSelectStrategy schemaSelectStrategy;
 
     /**
      * Ruft den Wert der ctx-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link Context }
+     *         possible object is {@link Context }
      *
      */
     public Context getCtx() {
@@ -64,8 +67,7 @@ public class Create {
      * Legt den Wert der ctx-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link Context }
+     *            allowed object is {@link Context }
      *
      */
     public void setCtx(Context value) {
@@ -76,8 +78,7 @@ public class Create {
      * Ruft den Wert der adminUser-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link User }
+     *         possible object is {@link User }
      *
      */
     public User getAdminUser() {
@@ -88,8 +89,7 @@ public class Create {
      * Legt den Wert der adminUser-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link User }
+     *            allowed object is {@link User }
      *
      */
     public void setAdminUser(User value) {
@@ -100,8 +100,7 @@ public class Create {
      * Ruft den Wert der auth-Eigenschaft ab.
      *
      * @return
-     *     possible object is
-     *     {@link Credentials }
+     *         possible object is {@link Credentials }
      *
      */
     public Credentials getAuth() {
@@ -112,12 +111,29 @@ public class Create {
      * Legt den Wert der auth-Eigenschaft fest.
      *
      * @param value
-     *     allowed object is
-     *     {@link Credentials }
+     *            allowed object is {@link Credentials }
      *
      */
     public void setAuth(Credentials value) {
         this.auth = value;
     }
 
+    /**
+     * Returns the schema select strategy.
+     * 
+     * @return The {@link SchemaSelectStrategy}
+     */
+    public SchemaSelectStrategy getSchemaSelectStrategy() {
+        return schemaSelectStrategy;
+    }
+
+    /**
+     * Sets the schema select strategy.
+     * 
+     * @param schemaSelectStrategy The {@link SchemaSelectStrategy}
+     */
+    public void setSchemaSelectStrategy(SchemaSelectStrategy schemaSelectStrategy) {
+        this.schemaSelectStrategy = schemaSelectStrategy;
+    }
+
 }
