@@ -42,6 +42,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
  *         &lt;element name="country_other" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="defaultSenderAddress" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="driveUserFolderMode" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="driveUserFolderModeAlt" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="default_group" type="{http://dataobjects.soap.admin.openexchange.com/xsd}Group" minOccurs="0"/>
  *         &lt;element name="department" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="display_name" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
@@ -152,6 +153,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
  *         &lt;element name="userfield18" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="userfield19" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="userfield20" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="primaryAccountName" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="convert_drive_user_folders" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/>
  *       &lt;/sequence>
  *     &lt;/restriction>
@@ -182,6 +184,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "countryHome",
     "countryOther",
     "driveUserFolderMode",
+    "driveUserFolderModeAlt",
     "defaultSenderAddress",
     "defaultGroup",
     "department",
@@ -294,6 +297,7 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "userfield18",
     "userfield19",
     "userfield20",
+    "primaryAccountName",
     "convertDriveUserFolders"
 })
 public class User {
@@ -335,8 +339,10 @@ public class User {
     protected String countryHome;
     @XmlElement(name = "country_other", nillable = true)
     protected String countryOther;
-    @XmlElement(name = "drive_folder_mode", nillable = true)
+    @XmlElement(name = "drive_user_folder_mode", nillable = true)
     protected String driveUserFolderMode;
+    @XmlElement(name = "drive_folder_mode", nillable = true)
+    protected String driveUserFolderModeAlt;
     @XmlElement(nillable = true)
     protected String defaultSenderAddress;
     @XmlElement(name = "default_group", nillable = true)
@@ -559,6 +565,8 @@ public class User {
     protected String userfield19;
     @XmlElement(nillable = true)
     protected String userfield20;
+    @XmlElement(nillable = true)
+    private String primaryAccountName;
     @XmlElement(name = "convert_drive_user_folders", nillable = true)
     protected Boolean convertDriveUserFolders;
 
@@ -1019,11 +1027,10 @@ public class User {
     public void setDefaultSenderAddress(final String value) {
         this.defaultSenderAddress = value;
     }
-    
 
     /**
      * Get driveUserFolderMode value.
-     * 
+     *
      * @return
      *      possible object is
      *     {@link String }
@@ -1044,6 +1051,29 @@ public class User {
         this.driveUserFolderMode = value;
     }
 
+    /**
+     * Get driveUserFolderModeAlt value.
+     *
+     * @return
+     *      possible object is
+     *     {@link String }
+     */
+    public String getDriveUserFolderModeAlt() {
+        return driveUserFolderModeAlt;
+    }
+
+    /**
+     * Set driveUserFolderModeAlt value..
+     *
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *
+     */
+    public void setDriveUserFolderModeAlt(String value) {
+        this.driveUserFolderModeAlt = value;
+    }
+
     /**
      * Ruft den Wert der defaultGroup-Eigenschaft ab.
      *
@@ -3756,6 +3786,24 @@ public class User {
         this.userfield20 = value;
     }
 
+    /**
+     * Gets the primaryAccountName
+     *
+     * @return The primaryAccountName
+     */
+    public String getPrimaryAccountName() {
+        return primaryAccountName;
+    }
+
+    /**
+     * Sets the primaryAccountName
+     *
+     * @param primaryAccountName The primaryAccountName to set
+     */
+    public void setPrimaryAccountName(String primaryAccountName) {
+        this.primaryAccountName = primaryAccountName;
+    }
+
     public Boolean isConvertDriveUserFolders() {
         return this.convertDriveUserFolders;
     }
